﻿using System;
using System.Collections.Generic;
using System.Text.RegularExpressions;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Input;
using Telerik.Windows.Controls;

namespace QuarterGaugeTheming
{
	public partial class MainPage : UserControl
	{
		Dictionary<string, ResourceDictionary> dictionaries = new Dictionary<string, ResourceDictionary>();

		Theme summer;
		Theme windows7;

		public MainPage()
		{
			InitializeComponent();

			this.summer = new SummerTheme();
			this.windows7 = new Windows7Theme();

			this.SetTheme(summer);

			this.MouseLeftButtonDown += new MouseButtonEventHandler(MainPage_MouseLeftButtonDown);
		}

		private void MainPage_MouseLeftButtonDown(object sender, MouseButtonEventArgs e)
		{
			Theme theme;
			Theme currentTheme = StyleManager.GetTheme(this.radGauge);
			if (currentTheme != null && currentTheme == this.summer)
			{
				theme = this.windows7;
			}
			else
			{
				theme = this.summer;
			}

			this.SetTheme(theme);
		}

		private void SetTheme(Theme theme)
		{
			this.gauge.ClearValue(FrameworkElement.StyleProperty);
			this.scale.ClearValue(FrameworkElement.StyleProperty);

			StyleManager.SetTheme(this.radGauge, theme);
			StyleManager.SetTheme(this.scale, theme);
			
			Regex regularExp = new Regex("/[^/]+xaml$"); 
            string uriString = regularExp.Replace(theme.Source.OriginalString, @"/Telerik.Windows.Controls.Gauge.xaml");
			ResourceDictionary dictionary = this.LoadDictionary(uriString);

			this.gauge.Style = dictionary["RadialGaugeQuarterCircleNEStyle"] as Style;
			this.scale.Style = dictionary["RadialScaleQuarterCircleNEStyle"] as Style;
		}

		private ResourceDictionary LoadDictionary(string uriString)
		{
			if (!this.dictionaries.ContainsKey(uriString))
			{
				ResourceDictionary dictionary = new ResourceDictionary();
				dictionary.Source = new Uri(uriString, UriKind.Relative);

				this.dictionaries.Add(uriString, dictionary);
			}

			return this.dictionaries[uriString];
		}
	}
}
